#!/usr/bin/env python
#pylint: skip-file
# This source code is licensed under the Apache license found in the
# LICENSE file in the root directory of this project.


import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class PolicypreviewApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient

    
    
    def getPolicyPreviewListByFilters(self, **kwargs):
        """Retrieves policy preview based on a given filter

        Args:
            
            policyScope, str: Retrieve policy previews for a given scope (required)
            
            
            scopeWirelessSegment, str: Retrieve policy previews for a given wireless segment, within a policyScope (policyScope is mandatory for this) (required)
            
            
            offset, str: Starting index of the resources (1 based) (required)
            
            
            limit, str: Number of resources to return (required)
            
            
        
        Returns: PolicyPreviewDTOListResult
        """

        allParams = ['policyScope', 'scopeWirelessSegment', 'offset', 'limit']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPolicyPreviewListByFilters" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/policy/preview'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'

        
        if ('policyScope' in params):
            queryParams['policyScope'] = self.apiClient.toPathValue(params['policyScope'])
        
        if ('scopeWirelessSegment' in params):
            queryParams['scopeWirelessSegment'] = self.apiClient.toPathValue(params['scopeWirelessSegment'])
        
        if ('offset' in params):
            queryParams['offset'] = self.apiClient.toPathValue(params['offset'])
        
        if ('limit' in params):
            queryParams['limit'] = self.apiClient.toPathValue(params['limit'])
        

        

        

        

        

        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)

        
        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'PolicyPreviewDTOListResult')
        return responseObject
        
        
        
    
    def update(self, **kwargs):
        """Update a policy preview

        Args:
            
            policyPreviewDTO, PolicyPreviewDTO: PolicyPreviewDTO (required)
            
            
        
        Returns: TaskIdResult
        """

        allParams = ['policyPreviewDTO']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method update" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/policy/preview'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'

        

        

        

        

        
        if ('policyPreviewDTO' in params):
            bodyParam = params['policyPreviewDTO']
        

        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)

        
        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject
        
        
        
    
    def add(self, **kwargs):
        """Create a policy preview

        Args:
            
            policyPreviewDTO, PolicyPreviewDTO: PolicyPreviewDTO (required)
            
            
        
        Returns: TaskIdResult
        """

        allParams = ['policyPreviewDTO']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method add" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/policy/preview'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'

        

        

        

        

        
        if ('policyPreviewDTO' in params):
            bodyParam = params['policyPreviewDTO']
        

        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)

        
        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject
        
        
        
    
    def getById(self, **kwargs):
        """Retrieves a policy preview based on its id

        Args:
            
            id, str: id (required)
            
            
        
        Returns: PolicyPreviewDTOResult
        """

        allParams = ['id']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/policy/preview/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'

        

        

        
        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)
        

        

        

        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)

        
        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'PolicyPreviewDTOResult')
        return responseObject
        
        
        
    
    def delete(self, **kwargs):
        """Deletes a policy preview by its id

        Args:
            
            id, str: id (required)
            
            
        
        Returns: TaskIdResult
        """

        allParams = ['id']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method delete" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/policy/preview/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'

        

        

        
        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)
        

        

        

        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)

        
        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject
        
        
        
    


